/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl;

import com.topcoder.document.index.persistence.IndexPersistenceException;


/**
 * <p>
 * This is an exception that signals persistence configuration issues when instantiating or initializing
 * persistence instances.
 * </p>
 *
 * <p>
 * It contains information about the exception that generated the problems.
 * The message passed in the constructor should be something meaningful to help the user to find the problem.
 * In addition to the message, the actual exception is passed to the user.
 * </p>
 *
 * <p>
 * Note, Ideally this exception should go into the com.topcoder.document.index.persistence package
 * but currently it will be placed in the common com.topcoder.document.index.persistence.impl package.
 * </p>
 *
 * @author AleaActaEst, TCSDEVELOPER
 * @version 1.0
 */
public class PersistenceConfigurationException extends IndexPersistenceException {
    /**
     * <p>
     * Create a new PersistenceConfigurationException exception instance initialized with the exception message.
     * </p>
     *
     * @param msg the message describing the cause of the exception.
     */
    public PersistenceConfigurationException(String msg) {
        super(msg);
    }

    /**
     * <p>
     * Create a new PersistenceConfigurationException exception instance initialized with the exception message and
     * the cause exception instance.
     * </p>
     *
     * @param msg the message describing the cause of the exception.
     * @param cause  Throwable cause of the exception.
     */
    public PersistenceConfigurationException(String msg, Throwable cause) {
        super(msg, cause);
    }
}
