/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl.xml;


/**
 * <p>
 * Constants that used in XmlIndexPersistence class.
 * Constants include the element tag names, attribute names used in xml files for XmlIndexPersistence, and the
 * templates for generating document index file.
 * </p>
 *
 * <p>
 * Note, this class only contains constants without any methods.
 * All the element tag names and attribute names are interned.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 *
 */
final class Constants {
    /**
     * <p>
     * Represents a place holder in template string for replacing.
     * </p>
     */
    static final String PLACE_HOLDER = "CONTENT";

    /**
     * <p>
     * Template xml header string in document index file.
     * </p>
     */
    static final String XML_HEADER = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\r\n";

    /**
     * <p>
     * Template doc start element string in document index file.
     * </p>
     */
    static final String DOC_START = "<doc xml:lang=\"CONTENT\">\r\n";

    /**
     * <p>
     * Template doc end element string in document index file.
     * </p>
     */
    static final String DOC_END = "</doc>";

    /**
     * <p>
     * Template document-index start element string in document index file.
     * </p>
     */
    static final String DOCUMENTINDEX_START = "    <document-index document-id=\"CONTENT\">\r\n";

    /**
     * <p>
     * Template document-index end element string in document index file.
     * </p>
     */
    static final String DOCUMENTINDEX_END = "    </document-index>\r\n";

    /**
     * <p>
     * Template word-source-data start element string in document index file.
     * </p>
     */
    static final String WORDSOURCEDATA_START = "        <word-source-data>\r\n";

    /**
     * <p>
     * Template word-source-data end element string in document index file.
     * </p>
     */
    static final String WORDSOURCEDATA_END = "        </word-source-data>\r\n";

    /**
     * <p>
     * Template source-identity element string in document index file.
     * </p>
     */
    static final String SOURCEIDENTITY_ELEMENT = "            <source-identity>CONTENT</source-identity>\r\n";

    /**
     * <p>
     * Template class-name element string in document index file.
     * </p>
     */
    static final String CLASSNAME_ELEMENT = "            <class-name>CONTENT</class-name>\r\n";

    /**
     * <p>
     * Template locale element string in document index file.
     * </p>
     */
    static final String LOCALE_ELEMENT = "            <locale CONTENT/>\r\n";

    /**
     * <p>
     * Template delimiters start element string in document index file.
     * </p>
     */
    static final String DELIMITERS_START = "            <delimiters>\r\n";

    /**
     * <p>
     * Template delimiters end element string in document index file.
     * </p>
     */
    static final String DELIMITERS_END = "            </delimiters>\r\n";

    /**
     * <p>
     * Template entry element string in document index file.
     * </p>
     */
    static final String ENTRY_ELEMENT = "                <entry delimiter=\"CONTENT\"/>\r\n";

    /**
     * <p>
     * Template word-index start element string in document index file.
     * </p>
     */
    static final String WORDINDEX_START = "        <word-index>\r\n";

    /**
     * <p>
     * Template word-index end element string in document index file.
     * </p>
     */
    static final String WORDINDEX_END = "        </word-index>\r\n";

    /**
     * <p>
     * Template word element string in document index file.
     * </p>
     */
    static final String WORD_ELEMENT = "            <word><![CDATA[CONTENT]]></word>\r\n";

    /**
     * <p>
     * Template pos element string in document index file.
     * </p>
     */
    static final String POS_ELEMENT = "            <pos>CONTENT</pos>\r\n";

    /**
     * <p>
     * Represents doc element tag name.
     * Interned.
     * </p>
     */
    static final String DOC = "doc".intern();

    /**
     * <p>
     * Represents documnt-index element tag name.
     * Interned.
     * </p>
     */
    static final String DOCUMENT_INDEX = "document-index".intern();

    /**
     * <p>
     * Represents document-id attribute name.
     * Interned.
     * </p>
     */
    static final String DOCUMENT_ID = "document-id".intern();

    /**
     * <p>
     * Represents word-source-data element tag name.
     * Interned.
     * </p>
     */
    static final String WORD_SOURCE_DATA = "word-source-data".intern();

    /**
     * <p>
     * Represents source-identity element tag name.
     * Interned.
     * </p>
     */
    static final String SOURCE_IDENTITY = "source-identity".intern();

    /**
     * <p>
     * Represents class-name element tag name.
     * Interned.
     * </p>
     */
    static final String CLASS_NAME = "class-name".intern();

    /**
     * <p>
     * Represents locale element tag name.
     * Interned.
     * </p>
     */
    static final String LOCALE = "locale".intern();

    /**
     * <p>
     * Represents language attribute name.
     * Interned.
     * </p>
     */
    static final String LANGUAGE = "language".intern();

    /**
     * <p>
     * Represents country attribute name.
     * Interned.
     * </p>
     */
    static final String COUNTRY = "country".intern();

    /**
     * <p>
     * Represents variant attribute name.
     * Interned.
     * </p>
     */
    static final String VARIANT = "variant".intern();

    /**
     * <p>
     * Represents delimiters element tag name.
     * Interned.
     * </p>
     */
    static final String DELIMITERS = "delimiters".intern();

    /**
     * <p>
     * Represents entry element tag name.
     * Interned.
     * </p>
     */
    static final String ENTRY = "entry".intern();

    /**
     * <p>
     * Represents delimiter attribute name.
     * Interned.
     * </p>
     */
    static final String DELIMITER = "delimiter".intern();

    /**
     * <p>
     * Represents word-index element tag name.
     * Interned.
     * </p>
     */
    static final String WORD_INDEX = "word-index".intern();

    /**
     * <p>
     * Represents word element tag name.
     * Interned.
     * </p>
     */
    static final String WORD = "word".intern();

    /**
     * <p>
     * Represents pos element tag name.
     * Interned.
     * </p>
     */
    static final String POS = "pos".intern();

    /**
     * <p>
     * Represents document-usage element tag name.
     * Interned.
     * </p>
     */
    static final String DOCUMENT_USAGE = "document-usage".intern();

    /**
     * <p>
     * Represents usage-count attribute name.
     * Interned.
     * </p>
     */
    static final String USAGE_COUNT = "usage-count".intern();

    /**
     * <p>
     * Represents collection-inclusion element tag name.
     * </p>
     */
    static final String COLLECTION_INCLUSION = "collection-inclusion".intern();

    /**
     * <p>
     * Represents collection element tag name.
     * </p>
     */
    static final String COLLECTION = "collection".intern();

    /**
     * <p>
     * Represents collection-id attribute name.
     * </p>
     */
    static final String COLLECTION_ID = "collection-id".intern();

    /**
     * <p>
     * Represents document-collection element tag name.
     * </p>
     */
    static final String DOCUMENT_COLLECTION = "document-collection".intern();

    /**
     * <p>
     * Represents documents element tag name.
     * </p>
     */
    static final String DOCUMENTS = "documents".intern();

    /**
     * <p>
     * This private constructor prevents to create a new instance.
     * </p>
     */
    private Constants() {
    }
}
