/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


/**
 * <p>
 * Unit test cases for PersistenceConfigurationException.
 * </p>
 *
 * <p>
 * This class is pretty simple. The test cases simply verifies the exception can be instantiated with the error message
 * and cause properly propagated, and that it comes with correct inheritance.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class PersistenceConfigurationExceptionTests extends TestCase {
    /** The error message used for testing. */
    private static final String ERROR_MESSAGE = "test error message";

    /** An exception instance used to create the PersistenceConfigurationException. */
    private static final Exception CAUSE_EXCEPTION = new NullPointerException();

    /**
     * Return the test suite of this class.
     *
     * @return the test suite of this class.
     */
    public static Test suite() {
        return new TestSuite(PersistenceConfigurationExceptionTests.class);
    }

    /**
     * <p>
     * Creation test.
     * </p>
     *
     * <p>
     * Verifies the error message is properly propagated.
     * </p>
     */
    public void testPersistenceConfigurationException1() {
        PersistenceConfigurationException pce = new PersistenceConfigurationException(ERROR_MESSAGE);
        assertNotNull("Unable to instantiate LoaderException.", pce);
        assertEquals("Error message is not properly propagated to super class.",
            ERROR_MESSAGE, pce.getMessage());
    }

    /**
     * <p>
     * Creation test.
     * </p>
     *
     * <p>
     * Verifies the error message and the cause are properly propagated.
     * </p>
     */
    public void testPersistenceConfigurationException2() {
        PersistenceConfigurationException pce = new PersistenceConfigurationException(ERROR_MESSAGE,
                CAUSE_EXCEPTION);

        assertNotNull("Unable to instantiate LoaderException.", pce);
        assertTrue("The error message should match",
            pce.getMessage().indexOf(ERROR_MESSAGE) >= 0);
        assertEquals("Cause is not properly propagated to super class.",
            CAUSE_EXCEPTION, pce.getCause());
    }

    /**
     * <p>
     * Inheritance test.
     * </p>
     *
     * <p>
     * Verifies PersistenceConfigurationException subclasses Exception.
     * </p>
     */
    public void testPersistenceConfigurationExceptionInheritance1() {
        PersistenceConfigurationException pce = new PersistenceConfigurationException(ERROR_MESSAGE);
        assertTrue("PersistenceConfigurationException does not subclass Exception.",
            pce instanceof Exception);
    }

    /**
     * <p>
     * Inheritance test.
     * </p>
     *
     * <p>
     * Verifies PersistenceConfigurationException subclasses Exception.
     * </p>
     */
    public void testPersistenceConfigurationExceptionInheritance2() {
        PersistenceConfigurationException pce = new PersistenceConfigurationException(ERROR_MESSAGE,
                CAUSE_EXCEPTION);
        assertTrue("PersistenceConfigurationException does not subclass Exception.",
            pce instanceof Exception);
    }
}
