/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl.xml;

import com.topcoder.document.index.persistence.TestHelper;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.util.ArrayList;
import java.util.List;

import javax.xml.parsers.SAXParser;


/**
 * <p>
 * Unit test cases for DocumentUsageHandler.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class DocumentUsageHandlerTests extends TestCase {
    /**
     * <p>
     * Represents the path of the xml file for testing.
     * </p>
     */
    private static final String XML_TEST_FILE = "test_files/handler_xml/document_usage_sample.xml";

    /**
     * <p>
     * DocumentUsageHandler instance for testing.
     * </p>
     */
    private DocumentUsageHandler handler;

    /**
     * <p>
     * Setup test environment.
     * </p>
     *
     * @throws Exception to JUnit.
     */
    protected void setUp() throws Exception {
        SAXParser parser = TestHelper.getSAXParser();
        handler = new DocumentUsageHandler();
        parser.parse(XML_TEST_FILE, handler);
    }

    /**
     * <p>
     * Tears down test environment.
     * </p>
     *
     */
    protected void tearDown() {
        handler = null;
    }

    /**
     * <p>
     * Return all tests.
     * </p>
     *
     * @return all tests
     */
    public static Test suite() {
        return new TestSuite(DocumentUsageHandlerTests.class);
    }

    /**
     * <p>
     * Tests DocumentUsageHandler#getDocumentUsageCount(String) for accuracy.
     * </p>
     */
    public void testGetDocumentUsageCount_Exist() {
        assertEquals("Failed to get correct usage count.", 2,
            handler.getDocumentUsageCount("16572").intValue());

        assertEquals("Failed to get correct usage count.", 0,
            handler.getDocumentUsageCount("46537").intValue());
    }

    /**
     * <p>
     * Tests DocumentUsageHandler#getDocumentUsageCount(String) for accuracy.
     * </p>
     */
    public void testGetDocumentUsageCount_NotExist() {
        assertNull("Expects to get null because the given document index doesn't exist.",
            handler.getDocumentUsageCount("2221222"));
    }

    /**
     * <p>
     * Tests DocumentUsageHandler#getDocumentCollectionList(String) for accuracy.
     * </p>
     */
    public void testGetDocumentCollectionList_Exist() {
        List collectionIds = new ArrayList();
        collectionIds.add("37684");
        collectionIds.add("11111");

        assertEquals("Failed to get correct collection id list.",
            collectionIds, handler.getDocumentCollectionList("16572"));

        assertTrue("Expects to get empty collection id list.",
            handler.getDocumentCollectionList("46537").isEmpty());
    }

    /**
     * <p>
     * Tests DocumentUsageHandler#getDocumentCollectionList(String) for accuracy.
     * </p>
     */
    public void testGetDocumentCollectionList_NotExist() {
        assertNull("Expects to get null because the given document index doesn't exist.",
            handler.getDocumentCollectionList("2221222"));
    }
}
